summaryrefslogtreecommitdiffstats
path: root/kio/bookmarks/kbookmarkmanager.h
diff options
context:
space:
mode:
Diffstat (limited to 'kio/bookmarks/kbookmarkmanager.h')
-rw-r--r--kio/bookmarks/kbookmarkmanager.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kio/bookmarks/kbookmarkmanager.h b/kio/bookmarks/kbookmarkmanager.h
index 403a2e1b3..e8fcd6196 100644
--- a/kio/bookmarks/kbookmarkmanager.h
+++ b/kio/bookmarks/kbookmarkmanager.h
@@ -57,7 +57,7 @@ class KIO_EXPORT KBookmarkManager : public TQObject, public DCOPObject
protected:
/**
* Creates a bookmark manager with a path to the bookmarks. By
* default, it will use the KDE standard dirs to find and create the
* correct location. If you are using your own app-specific
* bookmarks directory, you must instantiate this class with your
* own path <em>before</em> KBookmarkManager::managerForFile() is ever
@@ -152,10 +152,10 @@ public:
/**
* @return the bookmark designated by @p address
* @param address the address belonging to the bookmark you're looking for
* @param tolerate when true tries to find the most tolerable bookmark position
* @see KBookmark::address
*/
- KBookmark findByAddress( const TQString & address, bool tolerate = false );
+ KBookmark tqfindByAddress( const TQString & address, bool tolerate = false );
/**
* Saves the bookmark file and notifies everyone.
@@ -57,7 +57,7 @@ class KIO_EXPORT KBookmarkManager : public TQObject, public DCOPObject
/**
* Creates a bookmark manager with a path to the bookmarks. By
- * default, it will use the KDE standard dirs to find and create the
+ * default, it will use the KDE standard dirs to tqfind and create the
* correct location. If you are using your own app-specific
* bookmarks directory, you must instantiate this class with your
@@ -152,10 +152,10 @@ public:
* @return the bookmark designated by @p address
* @param address the address belonging to the bookmark you're looking for
- * @param tolerate when true tries to find the most tolerable bookmark position
+ * @param tolerate when true tries to tqfind the most tolerable bookmark position
* @see KBookmark::address
*/